# @summary Installs asdf version manager and configures user shell
#
# @example Basic usage
#   class { 'workstation::asdf::manage':
#     shell => 'bash',
#     user  => 'myuser',
#     home  => '/home/myuser',
#     repo  => 'https://github.com/asdf-vm/asdf.git'
#   }
#
# @see https://github.com/asdf-vm/asdf
#
# @param shell
#   The name of the shell binary to configure and set for the user
# @param user
#   The name of the user account to install asdf under
# @param home
#   The path to the home folder for the user
# @param repo
#   The asdf git repo url
#
class workstation::asdf::manage (
  Enum['bash', 'zsh', 'fish'] $shell = $workstation::shell,
  String[1] $user = $workstation::user,
  String[1] $home = $workstation::home,
  String[1] $repo = 'https://github.com/asdf-vm/asdf.git',
) {

  vcsrepo { "${home}/.asdf":
    ensure   => latest,
    provider => git,
    source   => $repo,
    owner    => $user,
  }

  case $shell {
    /^(bash|zsh)$/: {
      if $shell == 'zsh' {
        $config_file = "${home}/.zshrc"
      } else {
        $config_file = $facts['os']['family'] ? {
          'Darwin' => "${home}/.bash_profile",
          default  => "${home}/.bashrc",
        }
      }
      file_line { 'asdf_sh':
        path => $config_file,
        line => '. $HOME/.asdf/asdf.sh',
      }
      file_line { 'asdf_completions':
        path => $config_file,
        line => '. $HOME/.asdf/completions/asdf.bash',
      }
    }
    'fish': {
      file_line { 'source_asdf_fish':
        path    => "${home}/.config/fish/config.fish",
        line    => 'source ~/.asdf/asdf.fish',
        require => File[
          "${home}/.config/fish/",
          "${home}/.config/fish/config.fish",
        ],
      }
      exec { '/bin/cp .asdf/completions/asdf.fish .config/fish/completions':
        user    => $user,
        cwd     => $home,
        creates => "${home}/.config/fish/completions/asdf.fish",
        require => File["${home}/.config/fish/completions"],
      }
    }
  }

}
